from setuptools import setup

setup(
    name='hindsight',
    version='0.1.5',
    packages=['hindsight'],
    description='Python tools for Hindsight Software',
    author='Jack Bastow',
    author_email='jack.bastow@hindsightsoftware.co.uk',
    url='http://pypi.python.org/pypi/hindsight/',
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.txt').read(),
    entry_points={
        'console_scripts': [
            'behave-cli = hindsight.cli:main'
        ]
    },
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development"
    ],
    use_2to3=True
)